@@ -1105,10 +1105,11 @@ def upsert_timeseries(df: pandas.DataFrame, api_inputs: ApiInputs, is_local_time
     data_frame['TimestampLocalId'] = data_frame.apply(bin_to_15_minute_interval, args=('TimestampLocal',), axis=1)
 
     timestamp_format = "%Y-%m-%dT%H:%M:%SZ"
+    timestamp_normalized_format = "%Y-%m-%dT%H:%M:00Z"
     data_frame['Timestamp'] = data_frame['Timestamp'].dt.strftime(timestamp_format)
     data_frame['TimestampLocal'] = data_frame['TimestampLocal'].dt.strftime(timestamp_format)
-    data_frame['TimestampId'] = data_frame['TimestampId'].dt.strftime(timestamp_format)
-    data_frame['TimestampLocalId'] = data_frame['TimestampLocalId'].dt.strftime(timestamp_format)
+    data_frame['TimestampId'] = data_frame['TimestampId'].dt.strftime(timestamp_normalized_format)
+    data_frame['TimestampLocalId'] = data_frame['TimestampLocalId'].dt.strftime(timestamp_normalized_format)
 
     headers = api_inputs.api_headers.integration
 
