@@ -85,7 +85,8 @@ class Automation:
         message_count = 0
 
         with ServiceBusClient.from_connection_string(
-                _get_ingestion_service_bus_connection_string(api_inputs)) as client:
+                _get_ingestion_service_bus_connection_string(api_inputs, task.queue_type)) as client:
+            logger.info(f"Preparing Receiver for Queue: {task.queue_name}")
             with client.get_queue_receiver(task.queue_name,
                                            receive_mode=ServiceBusReceiveMode.RECEIVE_AND_DELETE) as receiver:
                 while True:
