@@ -5,12 +5,12 @@
 # --------------------------------------------------------------------------
 """Module defining the various definitions used internally by the pipeline module classes.
 """
-import uuid
+# import uuid
 from typing import List
-from .._utils._utils import (ApiInputs, convert_to_pascal_case, DiscoveryIntegrationInput)
+from .._utils._utils import convert_to_pascal_case
 from .._utils._constants import INTEGRATION_SETTINGS_EDITORS
-from ..integration import get_templates, get_units_of_measure
-from .. import initialize
+# from ..integration import get_templates, get_units_of_measure
+# from .. import initialize
 
 
 class BaseProperty:
@@ -79,12 +79,12 @@ class BaseProperty:
 
     @property
     def display_label(self) -> str:
-        "The display label for the given property"
+        """The display label for the given property"""
         return self._display_label
 
     @display_label.setter
     def display_label(self, value) -> str:
-        "The display label for the given property"
+        """The display label for the given property"""
         if type(value) != str:
             raise TypeError(f"The display_label parameter only accepts strings. ")
         elif type(value) == str and not 0 < len(value) <= 255:
@@ -118,7 +118,7 @@ class EventWorkOrderFieldDefinition(BaseProperty):
     property_name : str
         Must be in pascal case
     display_label : str
-        Pretty version of the property_name
+        Pretty version of the property_name (what is displayed in Events UI).
     editor : INTEGRATION_SETTINGS_EDITORS
         The editor used in the UI
     default_value : , default=None
@@ -140,7 +140,8 @@ class EventWorkOrderFieldDefinition(BaseProperty):
         default_value : , default=None
             The default value, if applicable, for the given property
         allowed_values : list, default=None
-            the set of allowed values (if applicable) for the given property_name. If editor=text_box, this should be None.
+            The set of allowed values (if applicable) for the given property_name. If editor=text_box, this should be
+            None.
         """
         super(EventWorkOrderFieldDefinition, self).__init__(
             property_name=property_name, display_label=display_label, editor=editor, default_value=default_value,
@@ -164,7 +165,8 @@ class AnalyticsSettings(BaseProperty):
         default_value : , default=None
             The default value, if applicable, for the given property
         allowed_values : list, default=None
-            the set of allowed values (if applicable) for the given property_name. If editor=text_box, this should be None.
+            the set of allowed values (if applicable) for the given property_name. If editor=text_box, this should be
+            None.
         """
         super(AnalyticsSettings, self).__init__(
             property_name=property_name, display_label=display_label, editor=editor, default_value=default_value,
@@ -172,8 +174,23 @@ class AnalyticsSettings(BaseProperty):
 
 
 class IntegrationSettings(BaseProperty):
-    """Class used for definining the UI editors, default values, etc for the key-values passed to integration_settings
-    dictionaries. """
+    """Class used for defining the UI editors, default values, etc for the key-values passed to integration_settings
+    dictionaries.
+
+    Parameters
+    ----------
+    property_name : str
+        Must be in pascal case
+    display_label : str
+        Pretty version of the property_name
+    editor : INTEGRATION_SETTINGS_EDITORS
+        The editor used in the UI
+    default_value : , default=None
+        The default value, if applicable, for the given property
+    allowed_values : list, default=None
+        the set of allowed values (if applicable) for the given property_name. If editor=text_box, this should be
+        None.
+    """
     def __init__(self, property_name, display_label, editor, default_value, allowed_values):
         """
 
@@ -188,7 +205,8 @@ class IntegrationSettings(BaseProperty):
         default_value : , default=None
             The default value, if applicable, for the given property
         allowed_values : list, default=None
-            the set of allowed values (if applicable) for the given property_name. If editor=text_box, this should be None.
+            the set of allowed values (if applicable) for the given property_name. If editor=text_box, this should be
+            None.
         """
         super(IntegrationSettings, self).__init__(
             property_name=property_name, display_label=display_label, editor=editor, default_value=default_value,
@@ -342,12 +360,12 @@ class IntegrationDeviceConfigPropertyDefinition(BaseProperty):
 
     @property
     def required_for_task(self) -> bool:
-        "Determines whether the given property is required for the task to run (Default Value = False). "
+        """"Determines whether the given property is required for the task to run (Default Value = False). """
         return self._required_for_task
 
     @required_for_task.setter
     def required_for_task(self, value) -> bool:
-        "Determines whether the given property is required for the task to run. "
+        """Determines whether the given property is required for the task to run. """
         if type(value) != bool:
             raise TypeError(f"The required_for_task parameter must be passed a boolean. ")
         self._required_for_task = value
@@ -484,9 +502,9 @@ class IntegrationDeviceDefinition:
     @address_label.setter
     def address_label(self, value) -> str:
         """If `expose_address` is True, tben this defines the label shown to user in UI."""
-        if type(value) != str and self.expose_address==False and value is not None:
+        if type(value) != str and self.expose_address == False and value is not None:
             raise TypeError(f"The address_label parameter only accepts strings. ")
-        elif value is None and self.expose_address==True:
+        elif value is None and self.expose_address == True:
             raise ValueError(f"address_label must be set to a string (in PascalCase) when expose_address is True. The "
                              f"parameter address_label can only be set to None when expose_address is False. ")
         elif type(value) == str and value != convert_to_pascal_case(value):
@@ -607,8 +625,8 @@ class IntegrationDeviceDefinition:
 #       #                            f"UnitOfMeasure should be set to None. ")
 #       #   elif self._object_property_type is None:
 #       #       if self.is_configuration == False:
-#       #           raise ValueError(f"unit_of_measure can only be set to None if the is_configuration parameter is set to "
-#       #                            f"True. ")
+#       #           raise ValueError(f"unit_of_measure can only be set to None if the is_configuration parameter is set"
+#       #                            f" to True. ")
 #
 #     @property
 #     def default_sensor_name(self):
