@@ -436,6 +436,11 @@ class QueueTask(Task):
     def queue_name(self) -> str:
         """The name of the queue to receive Data .. Name will actually be constructed as {ApiProjectId}_{queue_name} """
         pass
+    
+    @property
+    def queue_type(self) -> str:
+        """Type of the queue to receive data from"""
+        return 'DataIngestion'
 
     @property
     @abstractmethod
